%%% Aleph Parameters---------------------------------
:- set(caching,true).
:- set(check_useless,true).
:- set(clauselength,10).
:- set(depth,100000).
:- set(evalfn,coverage).
:- set(i,10). 
:- set(minacc,0.6).
:- set(minpos,10).
:- set(nodes,200000).
:- set(noise,50).
:- set(optimise_clauses,true). %performs query optimisations
:- set(verbosity,0). %A value of 0 shows very little.
%:- set(search,heuristic). 
:- set(explore,true). %explore more rules.


%%% Train and Test Sets---------------------------------
:- set(record,true).
%:- set(recordfile,'YN1OS1_YS1ON1.trace').
:- set(train_pos, 'MS.0').
:- set(train_neg, 'MN.0').


%%% Background Knowledge---------------------------------
:- consult(invasive_DCIS).
:- consult(extensional).
:- consult(otherMamm).


%%% Extensional Predicates---------------------------------
%prior surgery, palpable
:-modeb(*,prsr_side(+abnormalityID,#type_prsr_side)).
:-determination(invasive/1,prsr_side/2).
:-modeb(*,palp_side(+abnormalityID,#type_palp_side)).
:-determination(invasive/1,palp_side/2).


%old, location
:- modeb(1,first_diagnostic_study(+abnormalityID)).
:- determination(invasive/1,first_diagnostic_study/1).
:- modeb(*,old_study(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,old_study/2).
:- modeb(*,old_biopsy(+abnormalityID,-abnormalityID, #result)).
:- determination(invasive/1,old_biopsy/3).
:- modeb(*,old_biopsy_same_location(+abnormalityID,-abnormalityID, #result)).
:- determination(invasive/1,old_biopsy_same_location/3).

%mass
:- modeb(*,mssz_increase(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,mssz_increase/2).
:- modeb(*,mssz_decrease(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,mssz_decrease/2).

%BIRADS sides
:- modeb(1,this_side_BIRADS(+abnormalityID,-birads)).
:- modeb(1,this_side_BIRADS(+abnormalityID,#birads)).
:- determination(invasive/1,this_side_BIRADS/2).
:- modeb(1,other_side_BIRADS(+abnormalityID,-birads)).
:- modeb(1,other_side_BIRADS(+abnormalityID,#birads)).
:- determination(invasive/1,other_side_BIRADS/2).
:- modeb(*,this_side_birads_old_study(+abnormalityID,-abnormalityID,-birads)).
:- modeb(*,this_side_birads_old_study(+abnormalityID,-abnormalityID,#birads)).
:- determination(invasive/1,this_side_birads_old_study/3).
:- modeb(*,other_side_birads_old_study(+abnormalityID,-abnormalityID,-birads)).
:- modeb(*,other_side_birads_old_study(+abnormalityID,-abnormalityID,#birads)).
:- determination(invasive/1,other_side_birads_old_study/3).
:- modeb(*,combined_birads_old_study(+abnormalityID,-abnormalityID,-birads)).
:- modeb(*,combined_birads_old_study(+abnormalityID,-abnormalityID,#birads)).
:- determination(invasive/1,combined_birads_old_study/3).

%BIRADS decrease
:- modeb(*,this_side_birads_decrease(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,this_side_birads_decrease/2).
:- modeb(*,other_side_birads_decrease(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,other_side_birads_decrease/2).
:- modeb(*,combined_birads_decrease(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,combined_birads_decrease/2).

%BIRADS increase
:- modeb(*,this_side_birads_inc1(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,this_side_birads_inc1/2).
:- modeb(*,this_side_birads_inc2(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,this_side_birads_inc2/2).
:- modeb(*,this_side_birads_inc3(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,this_side_birads_inc3/2).
:- modeb(*,this_side_birads_inc4(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,this_side_birads_inc4/2).
:- modeb(*,this_side_birads_inc5(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,this_side_birads_inc5/2).
:- modeb(*,this_side_birads_inc6(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,this_side_birads_inc6/2).

:- modeb(*,other_side_birads_inc1(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,other_side_birads_inc1/2).
:- modeb(*,other_side_birads_inc2(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,other_side_birads_inc2/2).
:- modeb(*,other_side_birads_inc3(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,other_side_birads_inc3/2).
:- modeb(*,other_side_birads_inc4(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,other_side_birads_inc4/2).
:- modeb(*,other_side_birads_inc5(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,other_side_birads_inc5/2).
:- modeb(*,other_side_birads_inc6(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,other_side_birads_inc6/2).

:- modeb(*,combined_birads_inc1(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,combined_birads_inc1/2).
:- modeb(*,combined_birads_inc2(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,combined_birads_inc2/2).
:- modeb(*,combined_birads_inc3(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,combined_birads_inc3/2).
:- modeb(*,combined_birads_inc4(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,combined_birads_inc4/2).
:- modeb(*,combined_birads_inc5(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,combined_birads_inc5/2).
:- modeb(*,combined_birads_inc6(+abnormalityID,-abnormalityID)).
:- determination(invasive/1,combined_birads_inc6/2).


%%% Mass Comparison Predicates---------------------------------
:-modeb(1,mssz(+abnormalityID,-type_mssz)).
:-determination(invasive/1,mssz/2).

:- modeb(*,equal(+type_mssz,+type_mssz)).
:- modeb(*,equal(+type_mssz,#type_mssz)).
:- determination(invasive/1,equal/2).

:- modeb(*,gte(+type_mssz,+type_mssz)).
:- modeb(*,gte(+type_mssz,#interval_size)).
:- determination(invasive/1,gte/2).

:- modeb(*,lte(+type_mssz,+type_mssz)).
:- modeb(*,lte(+type_mssz,#interval_size)).
:- determination(invasive/1,lte/2).

gte(X,X) :- integer(X).
gte(X,Y) :- integer(X), var(Y), !, interval_size(Y), X >= Y. %if Y is unbound, don't backtrack and test below. bind it
gte(X,Y) :- integer(X), integer(Y), X >= Y. %both are bound

lte(X,X) :- integer(X).
lte(X,Y) :- integer(X), var(Y), !, interval_size(Y), X =< Y.
lte(X,Y) :- integer(X), integer(Y), X =< Y.

equal(X,X) :- integer(X). %equals itself, so get gte(B, #type_mssz), gte(B,B).

interval_size(10).
interval_size(20).
interval_size(30).
interval_size(40).
interval_size(50).
interval_size(60).
interval_size(70).
interval_size(80).
interval_size(90).


%%% BIRADS Comparison Predicates---------------------------------
:-modeb(1,biradscodescombined(+abnormalityID,-birads)).
:-modeb(1,biradscodescombined(+abnormalityID,#birads)).
:-determination(invasive/1,biradscodescombined/2).

:- modeb(*,bgt(+birads,+birads)).
:- modeb(*,bgt(+birads,#birads)).
:- determination(invasive/1,bgt/2).

:- modeb(*,blt(+birads,+birads)).
:- modeb(*,blt(+birads,#birads)).
:- determination(invasive/1,blt/2).

bgt(2,1). bgt(3,2). bgt(0,3). bgt(4,0). bgt(5,4). bgt(6,5).
bgt(3,1). bgt(0,2). bgt(4,3). bgt(5,0). bgt(6,4).
bgt(0,1). bgt(4,2). bgt(5,3). bgt(6,0).
bgt(4,1). bgt(5,2). bgt(6,3).
bgt(5,1). bgt(6,2).
bgt(6,1).

blt(1,2). blt(2,3). blt(3,0). blt(0,4). blt(4,5). blt(5,6).
blt(1,3). blt(2,0). blt(3,4). blt(0,5). blt(4,6).
blt(1,0). blt(2,4). blt(3,5). blt(0,6).
blt(1,4). blt(2,5). blt(3,6).
blt(1,5). blt(2,6).
blt(1,6).


%%% Basic Mode Declarations---------------------------------
:-modeh(1,invasive(+abnormalityID)).

:-modeb(1,fahx(+abnormalityID,#type_fahx)).
:-determination(invasive/1,fahx/2).
:-modeb(1,prhx(+abnormalityID,#type_prhx)).
:-determination(invasive/1,prhx/2).
:-modeb(1,svd(+abnormalityID,#type_svd)).
:-determination(invasive/1,svd/2).
:-modeb(1,indexam(+abnormalityID,#type_indexam)).
:-determination(invasive/1,indexam/2).
:-modeb(1,brdn(+abnormalityID,#type_brdn)).
:-determination(invasive/1,brdn/2).
:-modeb(1,biradscodescombined(+abnormalityID,#type_biradscodescombined)).
:-determination(invasive/1,biradscodescombined/2).
:-modeb(1,prinfin(+abnormalityID,#type_prinfin)).
:-determination(invasive/1,prinfin/2).
:-modeb(1,skrtr(+abnormalityID,#type_skrtr)).
:-determination(invasive/1,skrtr/2).
:-modeb(1,nprtr(+abnormalityID,#type_nprtr)).
:-determination(invasive/1,nprtr/2).
:-modeb(1,skthck(+abnormalityID,#type_skthck)).
:-determination(invasive/1,skthck/2).
:-modeb(1,skles(+abnormalityID,#type_skles)).
:-determination(invasive/1,skles/2).
:-modeb(1,arcdst(+abnormalityID,#type_arcdst)).
:-determination(invasive/1,arcdst/2).
:-modeb(1,cadt(+abnormalityID,#type_cadt)).
:-determination(invasive/1,cadt/2).
:-modeb(1,mamg(+abnormalityID,#type_mamg)).
:-determination(invasive/1,mamg/2).
:-modeb(1,camrp(+abnormalityID,#type_camrp)).
:-determination(invasive/1,camrp/2).
:-modeb(1,mash(+abnormalityID,#type_mash)).
:-determination(invasive/1,mash/2).
:-modeb(1,sctub(+abnormalityID,#type_sctub)).
:-determination(invasive/1,sctub/2).
:-modeb(1,scimln(+abnormalityID,#type_scimln)).
:-determination(invasive/1,scimln/2).
:-modeb(1,scasym(+abnormalityID,#type_scasym)).
:-determination(invasive/1,scasym/2).
:-modeb(1,scfoc(+abnormalityID,#type_scfoc)).
:-determination(invasive/1,scfoc/2).
:-modeb(1,mssz(+abnormalityID,#type_mssz)).
:-determination(invasive/1,mssz/2).



