%Author: HN
%Generates extensional predicates

:- use_module(library(system)).
:-[invasive_DCIS].
:-[otherMamm].

main :-
        open('extensional.yap',write,W),
	gen(W),
        close(W).

gen(W) :-
        ext(G),
        G, %execute goal
        format(W,'~q.~n',[G]),
        fail. %to baktrack. Repeat fail loop
gen(_). %so that we succeed at the very end.

%old, location
ext(first_diagnostic_study(_)).
ext(old_study(_,_)).
ext(old_biopsy(_,_,_)).
ext(old_biopsy_same_location(_,_,_)).

%mass
ext(mssz_increase(_,_)).
ext(mssz_decrease(_,_)).

%BIRADS sides
ext(this_side_BIRADS(_,_)).
ext(other_side_BIRADS(_,_)).
ext(this_side_birads_old_study(_,_,_)).
ext(other_side_birads_old_study(_,_,_)).
ext(combined_birads_old_study(_,_,_)).

%BIRADS decrease
ext(this_side_birads_decrease(_,_)).
ext(other_side_birads_decrease(_,_)).
ext(combined_birads_decrease(_,_)).

%BIRADS increase
ext(this_side_birads_inc1(_,_)).
ext(this_side_birads_inc2(_,_)).
ext(this_side_birads_inc3(_,_)).
ext(this_side_birads_inc4(_,_)).
ext(this_side_birads_inc5(_,_)).
ext(this_side_birads_inc6(_,_)).

ext(other_side_birads_inc1(_,_)).
ext(other_side_birads_inc2(_,_)).
ext(other_side_birads_inc3(_,_)).
ext(other_side_birads_inc4(_,_)).
ext(other_side_birads_inc5(_,_)).
ext(other_side_birads_inc6(_,_)).

ext(combined_birads_inc1(_,_)).
ext(combined_birads_inc2(_,_)).
ext(combined_birads_inc3(_,_)).
ext(combined_birads_inc4(_,_)).
ext(combined_birads_inc5(_,_)).
ext(combined_birads_inc6(_,_)).

% adjust palpable, personal history and prior surgery sides
ext(palp_side(_,_)).
ext(prsr_side(_,_)).
ext(prhx_side(_,_)).


first_diagnostic_study(Id) :- 
        svd(Id,Svd),	
	name(Svd,N),
	name('d',N),
	\+ old_study(Id,OldId).

old_study(Id,OldId) :-
	old_study(Id,OldId,OldStudyD).
old_study(Id,OldId,OldStudyD) :-
        mymrn(Id,MRN),
        studydate(Id,StudyD),
	mymrn(OldId,MRN),
        studydate(OldId,OldStudyD),
        OldStudyD < StudyD.

old_biopsy(Id,OldId,Result) :-
	old_biopsy(Id,OldId,OldBiopsyD, Result).
old_biopsy(Id,OldId,OldBiopsyD, Result) :-
        mymrn(Id,MRN),
        studydate(Id,StudyD),
	mymrn(OldId,MRN),
        studydate(OldId,OldStudyD),
	biopsydate(OldId,OldBiopsyD),
        OldStudyD < StudyD,
	qualdx(OldId,Result).

old_biopsy_same_location(Id,OldId, Result) :-
	old_biopsy_same_location(Id,OldId,OldBiopsyD, Result).
old_biopsy_same_location(Id,OldId,OldBiopsyD,Result) :-
	old_biopsy(Id,OldId,OldBiopsyD,Result),
	same_location(Id,OldId).

same_location(Id1, Id2) :-
        mymrn(Id1,MRN),
	side(Id1, S),
	clock(Id1, C1),
        mymrn(Id2,MRN),
	Id1 \= Id2,
	side(Id2, S),
	clock(Id2,C2),
	location_error(C1,C2,1).

%the error in the quadrant location
location_error(Nb1,Nb2,Nb) :-
	abs(Nb1-Nb2) mod (9-Nb) =< Nb.

side(Id, S) :-
	tumorloc(Id, Loc),
	sub_atom(Loc, 0, 1, 1, S).

clock(Id, C) :-
	tumorloc(Id, Loc),
	sub_atom(Loc, 1, 1, 0, Chr),
	char_type(Chr,digit(C)).

mssz_increase(Id, OldId) :-
	old_study(Id,OldId,OldStudyD),
	mssz(Id, Size),
	mssz(OldId, OldSize),
	integer(Size),
	integer(OldSize),
	Size > OldSize.

mssz_decrease(Id, OldId) :-
	old_study(Id,OldId,OldStudyD),
	mssz(Id, Size),
	mssz(OldId, OldSize),
	integer(Size),
	integer(OldSize),
	Size < OldSize.

this_side_BIRADS(Id, BIRADS) :-
	this_side_BIRADS(Id, BIRADS, S).
this_side_BIRADS(Id, BIRADS, S) :-
	side(Id, S),
	name(S,N),
	name('l',N),
	biradscodesleft(Id, BIRADS).
this_side_BIRADS(Id, BIRADS, S) :-
	side(Id, S),
	name(S,N),
	name('r',N),
	biradscodesright(Id, BIRADS).


other_side_BIRADS(Id, BIRADS) :-
	other_side_BIRADS(Id, BIRADS, S).
other_side_BIRADS(Id, BIRADS, S) :-
	side(Id, S),
	name(S,N),
	name('l',N),
	biradscodesright(Id, BIRADS).
other_side_BIRADS(Id, BIRADS,S) :-
	side(Id, S),
	name(S,N),
	name('r',N),
	biradscodesleft(Id, BIRADS).


this_side_birads_old_study(Id, OldId, OldBIRADS) :-
	this_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_old_study(Id, OldId, OldBIRADS) :-
	this_side_birads_older_study(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_BIRADS(Id, BIRADS, S),
	old_study(Id,OldId,OldStudyD),
	name(S,N),
	name('l',N),
	biradscodesleft(OldId, OldBIRADS).
this_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_BIRADS(Id, BIRADS, S),
	old_study(Id,OldId,OldStudyD),
	name(S,N),
	name('r',N),
	biradscodesright(OldId, OldBIRADS).
this_side_birads_older_study(OldId, OlderId, OldBIRADS, OlderBIRADS, S) :-
	this_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	this_side_birads_old_study(Id, OlderId, BIRADS, OlderBIRADS, S),
	old_study(OldId,OlderId,OlderStudyD).


other_side_birads_old_study(Id, OldId, OldBIRADS) :-
	other_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_old_study(Id, OldId, OldBIRADS) :-
	other_side_birads_older_study(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_BIRADS(Id, BIRADS, S),
	old_study(Id,OldId,OldStudyD),
	name(S,N),
	name('l',N),
	biradscodesright(OldId, OldBIRADS).
other_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_BIRADS(Id, BIRADS, S),
	old_study(Id,OldId,OldStudyD),
	name(S,N),
	name('r',N),
	biradscodesleft(OldId, OldBIRADS).
other_side_birads_older_study(OldId, OlderId, OldBIRADS, OlderBIRADS, S) :-
	other_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	other_side_birads_old_study(Id, OlderId, BIRADS, OlderBIRADS, S),
	old_study(OldId,OlderId,OlderStudyD).

combined_birads_old_study(Id, OldId, OldBIRADS) :-
	combined_birads_old_study(Id, OldId, BIRADS, OldBIRADS).
combined_birads_old_study(Id, OldId, BIRADS, OldBIRADS) :-
	biradscodescombined(Id, BIRADS),
	old_study(Id,OldId,OldStudyD),
	biradscodescombined(OldId, OldBIRADS).


this_side_birads_decrease(Id, OldId) :-
	this_side_birads_decrease(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_decrease(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	\+bgt(BIRADS, OldBIRADS). % not bgt
	
other_side_birads_decrease(Id, OldId) :-
	other_side_birads_decrease(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_decrease(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	\+bgt(BIRADS, OldBIRADS). % not bgt

combined_birads_decrease(Id, OldId) :-
	combined_birads_decrease(Id, OldId, BIRADS, OldBIRADS).
combined_birads_decrease(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_old_study(Id, OldId, BIRADS, OldBIRADS),
	BIRADS \= OldBIRADS,
	\+bgt(BIRADS, OldBIRADS). % not bgt

bgt(2,1). bgt(3,2). bgt(0,3). bgt(4,0). bgt(5,4). bgt(6,5).
bgt(3,1). bgt(0,2). bgt(4,3). bgt(5,0). bgt(6,4).
bgt(0,1). bgt(4,2). bgt(5,3). bgt(6,0).
bgt(4,1). bgt(5,2). bgt(6,3).
bgt(5,1). bgt(6,2).
bgt(6,1).

this_side_birads_inc1(Id, OldId) :-
	this_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	inc1(BIRADS, OldBIRADS).
this_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S).

this_side_birads_inc2(Id, OldId) :-
	this_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	inc2(BIRADS, OldBIRADS).
this_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S).

this_side_birads_inc3(Id, OldId) :-
	this_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	inc3(BIRADS, OldBIRADS).
this_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S).

this_side_birads_inc4(Id, OldId) :-
	this_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	inc4(BIRADS, OldBIRADS).
this_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S).

this_side_birads_inc5(Id, OldId) :-
	this_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	inc5(BIRADS, OldBIRADS).
this_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S).

this_side_birads_inc6(Id, OldId) :-
	this_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S).
this_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S) :-
	this_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	inc6(BIRADS, OldBIRADS).


other_side_birads_inc1(Id, OldId) :-
	other_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	inc1(BIRADS, OldBIRADS).
other_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc1(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S).

other_side_birads_inc2(Id, OldId) :-
	other_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	inc2(BIRADS, OldBIRADS).
other_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc2(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S).

other_side_birads_inc3(Id, OldId) :-
	other_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	inc3(BIRADS, OldBIRADS).
other_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc3(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S).

other_side_birads_inc4(Id, OldId) :-
	other_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	inc4(BIRADS, OldBIRADS).
other_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc4(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S).

other_side_birads_inc5(Id, OldId) :-
	other_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	inc5(BIRADS, OldBIRADS).
other_side_birads_inc5(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S).

other_side_birads_inc6(Id, OldId) :-
	other_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S).
other_side_birads_inc6(Id, OldId, BIRADS, OldBIRADS, S) :-
	other_side_birads_old_study(Id, OldId, BIRADS, OldBIRADS, S),
	BIRADS \= OldBIRADS,
	inc6(BIRADS, OldBIRADS).

combined_birads_inc1(Id, OldId) :-
	combined_birads_inc1(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc1(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_old_study(Id, OldId, BIRADS, OldBIRADS),
	BIRADS \= OldBIRADS,
	inc1(BIRADS, OldBIRADS).
combined_birads_inc1(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc2(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc1(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc3(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc1(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc4(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc1(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc5(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc1(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc6(Id, OldId, BIRADS, OldBIRADS).

combined_birads_inc2(Id, OldId) :-
	combined_birads_inc2(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc2(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_old_study(Id, OldId, BIRADS, OldBIRADS),
	BIRADS \= OldBIRADS,
	inc2(BIRADS, OldBIRADS).
combined_birads_inc2(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc3(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc2(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc4(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc2(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc5(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc2(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc6(Id, OldId, BIRADS, OldBIRADS).

combined_birads_inc3(Id, OldId) :-
	combined_birads_inc3(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc3(Id, OldId, BIRADS, OldBIRADS) :-
 	combined_birads_old_study(Id, OldId, BIRADS, OldBIRADS),
	BIRADS \= OldBIRADS,
	inc3(BIRADS, OldBIRADS).
combined_birads_inc3(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc4(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc3(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc5(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc3(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc6(Id, OldId, BIRADS, OldBIRADS).

combined_birads_inc4(Id, OldId) :-
	combined_birads_inc4(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc4(Id, OldId, BIRADS, OldBIRADS) :-
 	combined_birads_old_study(Id, OldId, BIRADS, OldBIRADS),
	BIRADS \= OldBIRADS,
	inc4(BIRADS, OldBIRADS).
combined_birads_inc4(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc5(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc4(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc6(Id, OldId, BIRADS, OldBIRADS).

combined_birads_inc5(Id, OldId) :-
	combined_birads_inc5(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc5(Id, OldId, BIRADS, OldBIRADS) :-
 	combined_birads_old_study(Id, OldId, BIRADS, OldBIRADS),
	BIRADS \= OldBIRADS,
	inc5(BIRADS, OldBIRADS).
combined_birads_inc5(Id, OldId, BIRADS, OldBIRADS) :-
	combined_birads_inc6(Id, OldId, BIRADS, OldBIRADS).

combined_birads_inc6(Id, OldId) :-
	combined_birads_inc6(Id, OldId, BIRADS, OldBIRADS).
combined_birads_inc6(Id, OldId, BIRADS, OldBIRADS) :-
  	combined_birads_old_study(Id, OldId, BIRADS, OldBIRADS),
	BIRADS \= OldBIRADS,
	inc6(BIRADS, OldBIRADS).

inc1(2,1). inc1(3,2). inc1(0,3). inc1(4,0). inc1(5,4). inc1(6,5).
inc2(3,1). inc2(0,2). inc2(4,3). inc2(5,0). inc2(6,4).
inc3(0,1). inc3(4,2). inc3(5,3). inc3(6,0).
inc4(4,1). inc4(5,2). inc4(6,3).
inc5(5,1). inc5(6,2).
inc6(6,1).

%this side palpable
palp_side(Id, 'this') :-
	side(Id, S),
	palp(Id, S).

%other side palpable
palp_side(Id, 'other') :-
	side(Id, S1),
	palp(Id, S2),
	name(S1,N),
	name('r',N),
	name(S2,M),
	name('l',M).
palp_side(Id, 'other') :-
	side(Id, S1),
	palp(Id, S2),
	name(S1,N),
	name('l',N),
	name(S2,M),
	name('r',M).

%both
palp_side(Id, 'both') :-
	palp(Id, S),
	name(S,N),
	name('b',N).
palp_side(Id, 'this') :-
	palp(Id, S),
	name(S,N),
	name('b',N).
palp_side(Id, 'other') :-
	palp(Id, S),
	name(S,N),
	name('b',N).

%none, not entered
palp_side(Id, 'none') :-
	palp(Id, S),
	name(S,N),
	name('n',N).
palp_side(Id, 'notent') :-
	palp(Id, S),
	name(S,N),
	name('notent',N).


%this side prior surgery
prsr_side(Id, 'this') :-
	side(Id, S),
	prsr(Id, S).

%other side prior surgery
prsr_side(Id, 'other') :-
	side(Id, S1),
	prsr(Id, S2),
	name(S1,N),
	name('r',N),
	name(S2,M),
	name('l',M).
prsr_side(Id, 'other') :-
	side(Id, S1),
	prsr(Id, S2),
	name(S1,N),
	name('l',N),
	name(S2,M),
	name('r',M).

%both
prsr_side(Id, 'both') :-
	prsr(Id, S),
	name(S,N),
	name('b',N).
prsr_side(Id, 'this') :-
	prsr(Id, S),
	name(S,N),
	name('b',N).
prsr_side(Id, 'other') :-
	prsr(Id, S),
	name(S,N),
	name('b',N).

%none, not entered
prsr_side(Id, 'none') :-
	prsr(Id, S),
	name(S,N),
	name('n',N).
prsr_side(Id, 'notent') :-
	prsr(Id, S),
	name(S,N),
	name('notent',N).



%this side personal hist
prhx_side(Id, 'this') :-
	side(Id, S),
	prhx(Id, S).

%other side personal hist
prhx_side(Id, 'other') :-
	side(Id, S1),
	prhx(Id, S2),
	name(S1,N),
	name('r',N),
	name(S2,M),
	name('l',M).
prhx_side(Id, 'other') :-
	side(Id, S1),
	prhx(Id, S2),
	name(S1,N),
	name('l',N),
	name(S2,M),
	name('r',M).

%both
prhx_side(Id, 'both') :-
	prhx(Id, S),
	name(S,N),
	name('b',N).
prhx_side(Id, 'this') :-
	prhx(Id, S),
	name(S,N),
	name('b',N).
prhx_side(Id, 'other') :-
	prhx(Id, S),
	name(S,N),
	name('b',N).

%none, not entered
prhx_side(Id, 'none') :-
	prhx(Id, S),
	name(S,N),
	name('n',N).
prsr_hx(Id, 'notent') :-
	prhx(Id, S),
	name(S,N),
	name('notent',N).

:- main.
